"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class BatchStats {
    constructor({ commands, start = Date.now() }) {
        this.start = start;
        this.end = null;
        this.commands = commands;
        this.response = null;
        this.error = null;
    }
    get commandCount() {
        return this.commands.length;
    }
    get responseCount() {
        return (this.response || []).length;
    }
    get timeInRedis() {
        const end = this.end || Date.now();
        return end - this.start;
    }
    finish(error, response) {
        this.end = Date.now();
        this.error = error;
        this.response = response;
    }
}
exports.BatchStats = BatchStats;
class RedisStats {
    constructor() {
        this.batches = new Set();
        this.batchCount = 0;
        this.commandCount = 0;
        this.responseCount = 0;
        this.timeInRedis = 0;
        this.lastBatch = null;
    }
    startBatch(commands) {
        const batch = new BatchStats({ commands });
        this.batches.add(batch);
        this.batchCount++;
        this.commandCount += batch.commandCount;
        return batch;
    }
    endBatch(batch, error, response) {
        batch.finish(error, response);
        this.timeInRedis += batch.timeInRedis;
        this.responseCount += batch.responseCount;
        this.lastBatch = batch;
        this.batches.delete(batch);
    }
    toJSON() {
        const { batches, batchCount, commandCount, responseCount, timeInRedis, lastBatch } = this;
        return {
            batches: Array.from(batches),
            batchCount,
            commandCount,
            responseCount,
            timeInRedis,
            lastBatch
        };
    }
}
exports.RedisStats = RedisStats;
